@@ -1,7 +1,4 @@
 # -*- mode: python; coding: utf-8 -*-
-from __future__ import absolute_import
-import six
-
 
 class FalseMeta(type):
     def __bool__(self):  # pragma: no cover
@@ -13,9 +10,9 @@ class FalseMeta(type):
     __nonzero__ = __bool__
 
 
-class UnknownLength(six.with_metaclass(FalseMeta, object)):
+class UnknownLength(metaclass=FalseMeta):
     pass
 
 
-class Undefined(six.with_metaclass(FalseMeta, object)):
+class Undefined(metaclass=FalseMeta):
     pass
